YouKuDownLoader
===============

.. image:: https://img.shields.io/pypi/v/ykdl.svg
   :target: https://pypi.python.org/pypi/ykdl
.. image:: https://travis-ci.org/zhangn1985/ykdl.svg
   :target: https://travis-ci.org/zhangn1985/ykdl


a video downloader focus on China mainland video sites.

website: https://github.com/zhangn1985/ykdl

this project is a fork of `you-get <https://github.com/soimort/you-get>`_ with below changes.

1. Structured source code
2. focus on China mainland video sites
3. support Python2

Simple installation guild:

Linux/debian:

0. sudo apt-get install ffmpeg mpv python3-crypto python3-pip python3-m3u8
1. pip3 install ykdl --upgrade --user
2. add ~/.local/bin to your PATH

Windows:

0. install python3 from python.org
1. pip install --upgrade ykdl
2. install deps: `FFMPEG <https://ffmpeg.zeranoe.com/builds/>`_ `MPV <https://mpv.srsfckn.biz/>`_ to system PATH

Other Linux: please follow debian

Other OS: please DIY.


Site status:

please check wiki page: `sites-status <https://github.com/zhangn1985/ykdl/wiki/sites-status>`_

file bugs or requirements are welcome

submit PRs are welcome
